@@ -204,6 +204,7 @@ class PerturbFlow(nn.Module):
                     post_act_fct=post_act_fct,
                     allow_broadcast=self.allow_broadcast,
                     use_cuda=self.use_cuda,
+                    bias=False,
                 )
                 )
             
@@ -662,15 +663,15 @@ class PerturbFlow(nn.Module):
         cb = tensor_to_numpy(cb)
         return cb
 
-    def _get_basis_embedding(self, xs):           
+    def _get_basal_embedding(self, xs):           
         zns, _ = self.encoder_zn(xs)
         return zns 
     
-    def get_basis_embedding(self, 
+    def get_basal_embedding(self, 
                              xs, 
                              batch_size: int = 1024):
         """
-        Return cells' basis latent representations
+        Return cells' basal latent representations
 
         Parameters
         ----------
@@ -691,7 +692,7 @@ class PerturbFlow(nn.Module):
         Z = []
         with tqdm(total=len(dataloader), desc='', unit='batch') as pbar:
             for X_batch, _ in dataloader:
-                zns = self._get_basis_embedding(X_batch)
+                zns = self._get_basal_embedding(X_batch)
                 Z.append(tensor_to_numpy(zns))
                 pbar.update(1)
 
